from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import key_point_pb2 as _key_point_pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import point3f_pb2 as _point3f_pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import sensor_data_pb2 as _sensor_data_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Node(_message.Message):
    __slots__ = ["id", "map_id", "weight", "stamp", "label", "pose", "word_id_keys", "word_id_values", "word_kpts", "word_pts", "word_descriptors", "data"]
    ID_FIELD_NUMBER: _ClassVar[int]
    MAP_ID_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    WORD_ID_KEYS_FIELD_NUMBER: _ClassVar[int]
    WORD_ID_VALUES_FIELD_NUMBER: _ClassVar[int]
    WORD_KPTS_FIELD_NUMBER: _ClassVar[int]
    WORD_PTS_FIELD_NUMBER: _ClassVar[int]
    WORD_DESCRIPTORS_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    id: int
    map_id: int
    weight: int
    stamp: float
    label: str
    pose: _pose_pb2.Pose
    word_id_keys: _containers.RepeatedScalarFieldContainer[int]
    word_id_values: _containers.RepeatedScalarFieldContainer[int]
    word_kpts: _containers.RepeatedCompositeFieldContainer[_key_point_pb2.KeyPoint]
    word_pts: _containers.RepeatedCompositeFieldContainer[_point3f_pb2.Point3f]
    word_descriptors: _containers.RepeatedScalarFieldContainer[int]
    data: _sensor_data_pb2.SensorData
    def __init__(self, id: _Optional[int] = ..., map_id: _Optional[int] = ..., weight: _Optional[int] = ..., stamp: _Optional[float] = ..., label: _Optional[str] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., word_id_keys: _Optional[_Iterable[int]] = ..., word_id_values: _Optional[_Iterable[int]] = ..., word_kpts: _Optional[_Iterable[_Union[_key_point_pb2.KeyPoint, _Mapping]]] = ..., word_pts: _Optional[_Iterable[_Union[_point3f_pb2.Point3f, _Mapping]]] = ..., word_descriptors: _Optional[_Iterable[int]] = ..., data: _Optional[_Union[_sensor_data_pb2.SensorData, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RxmSVSISV(_message.Message):
    __slots__ = ["header", "svid", "sv_flag", "azim", "elev", "age"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SVID_FIELD_NUMBER: _ClassVar[int]
    SV_FLAG_FIELD_NUMBER: _ClassVar[int]
    AZIM_FIELD_NUMBER: _ClassVar[int]
    ELEV_FIELD_NUMBER: _ClassVar[int]
    AGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    svid: int
    sv_flag: int
    azim: int
    elev: int
    age: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., svid: _Optional[int] = ..., sv_flag: _Optional[int] = ..., azim: _Optional[int] = ..., elev: _Optional[int] = ..., age: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SetPidGainsRequest(_message.Message):
    __slots__ = ["p", "i", "d", "i_clamp", "antiwindup"]
    P_FIELD_NUMBER: _ClassVar[int]
    I_FIELD_NUMBER: _ClassVar[int]
    D_FIELD_NUMBER: _ClassVar[int]
    I_CLAMP_FIELD_NUMBER: _ClassVar[int]
    ANTIWINDUP_FIELD_NUMBER: _ClassVar[int]
    p: float
    i: float
    d: float
    i_clamp: float
    antiwindup: bool
    def __init__(self, p: _Optional[float] = ..., i: _Optional[float] = ..., d: _Optional[float] = ..., i_clamp: _Optional[float] = ..., antiwindup: bool = ...) -> None: ...

class SetPidGainsResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.autoware_planning_msgs.msg import lanelet_segment_pb2 as _lanelet_segment_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LaneletRoute(_message.Message):
    __slots__ = ["header", "ros2_header", "start_pose", "goal_pose", "segments", "uuid", "allow_modification"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    START_POSE_FIELD_NUMBER: _ClassVar[int]
    GOAL_POSE_FIELD_NUMBER: _ClassVar[int]
    SEGMENTS_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    ALLOW_MODIFICATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    start_pose: _pose_pb2.Pose
    goal_pose: _pose_pb2.Pose
    segments: _containers.RepeatedCompositeFieldContainer[_lanelet_segment_pb2.LaneletSegment]
    uuid: _uuid_pb2.UUID
    allow_modification: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., start_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., goal_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., segments: _Optional[_Iterable[_Union[_lanelet_segment_pb2.LaneletSegment, _Mapping]]] = ..., uuid: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., allow_modification: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_safevisionary_interfaces/msg/field_information.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/jazzy/sick_safevisionary_interfaces/msg/field_information.proto\x12<make87_messages_ros2.jazzy.sick_safevisionary_interfaces.msg\"{\n\x10\x46ieldInformation\x12\x10\n\x08\x66ield_id\x18\x01 \x01(\r\x12\x14\n\x0c\x66ield_set_id\x18\x02 \x01(\r\x12\x14\n\x0c\x66ield_result\x18\x03 \x01(\r\x12\x13\n\x0b\x65val_method\x18\x04 \x01(\r\x12\x14\n\x0c\x66ield_active\x18\x05 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_safevisionary_interfaces.msg.field_information_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FIELDINFORMATION']._serialized_start=150
  _globals['_FIELDINFORMATION']._serialized_end=273
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/plansys2_msgs/srv/affect_param.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.plansys2_msgs.msg import param_pb2 as make87__messages__ros2_dot_humble_dot_plansys2__msgs_dot_msg_dot_param__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/plansys2_msgs/srv/affect_param.proto\x12-make87_messages_ros2.humble.plansys2_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/plansys2_msgs/msg/param.proto\"\x87\x01\n\x12\x41\x66\x66\x65\x63tParamRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x43\n\x05param\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.humble.plansys2_msgs.msg.Param\"h\n\x13\x41\x66\x66\x65\x63tParamResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x12\n\nerror_info\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.plansys2_msgs.srv.affect_param_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AFFECTPARAMREQUEST']._serialized_start=210
  _globals['_AFFECTPARAMREQUEST']._serialized_end=345
  _globals['_AFFECTPARAMRESPONSE']._serialized_start=347
  _globals['_AFFECTPARAMRESPONSE']._serialized_end=451
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrVehicle2(_message.Message):
    __slots__ = ["header", "scan_index_ack", "use_angle_misalignment", "clear_faults", "high_yaw_angle", "mr_only_transmit", "lr_only_transmit", "angle_misalignment", "lateral_mounting_offset", "radar_cmd_radiate", "blockage_disable", "maximum_tracks", "turn_signal_status", "vehicle_speed_validity", "mmr_upside_down", "grouping_mode", "wiper_status", "raw_data_enable"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SCAN_INDEX_ACK_FIELD_NUMBER: _ClassVar[int]
    USE_ANGLE_MISALIGNMENT_FIELD_NUMBER: _ClassVar[int]
    CLEAR_FAULTS_FIELD_NUMBER: _ClassVar[int]
    HIGH_YAW_ANGLE_FIELD_NUMBER: _ClassVar[int]
    MR_ONLY_TRANSMIT_FIELD_NUMBER: _ClassVar[int]
    LR_ONLY_TRANSMIT_FIELD_NUMBER: _ClassVar[int]
    ANGLE_MISALIGNMENT_FIELD_NUMBER: _ClassVar[int]
    LATERAL_MOUNTING_OFFSET_FIELD_NUMBER: _ClassVar[int]
    RADAR_CMD_RADIATE_FIELD_NUMBER: _ClassVar[int]
    BLOCKAGE_DISABLE_FIELD_NUMBER: _ClassVar[int]
    MAXIMUM_TRACKS_FIELD_NUMBER: _ClassVar[int]
    TURN_SIGNAL_STATUS_FIELD_NUMBER: _ClassVar[int]
    VEHICLE_SPEED_VALIDITY_FIELD_NUMBER: _ClassVar[int]
    MMR_UPSIDE_DOWN_FIELD_NUMBER: _ClassVar[int]
    GROUPING_MODE_FIELD_NUMBER: _ClassVar[int]
    WIPER_STATUS_FIELD_NUMBER: _ClassVar[int]
    RAW_DATA_ENABLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    scan_index_ack: int
    use_angle_misalignment: bool
    clear_faults: bool
    high_yaw_angle: int
    mr_only_transmit: bool
    lr_only_transmit: bool
    angle_misalignment: float
    lateral_mounting_offset: float
    radar_cmd_radiate: bool
    blockage_disable: bool
    maximum_tracks: int
    turn_signal_status: int
    vehicle_speed_validity: bool
    mmr_upside_down: bool
    grouping_mode: int
    wiper_status: bool
    raw_data_enable: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., scan_index_ack: _Optional[int] = ..., use_angle_misalignment: bool = ..., clear_faults: bool = ..., high_yaw_angle: _Optional[int] = ..., mr_only_transmit: bool = ..., lr_only_transmit: bool = ..., angle_misalignment: _Optional[float] = ..., lateral_mounting_offset: _Optional[float] = ..., radar_cmd_radiate: bool = ..., blockage_disable: bool = ..., maximum_tracks: _Optional[int] = ..., turn_signal_status: _Optional[int] = ..., vehicle_speed_validity: bool = ..., mmr_upside_down: bool = ..., grouping_mode: _Optional[int] = ..., wiper_status: bool = ..., raw_data_enable: bool = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.rolling.soccer_vision_attribute_msgs.msg import confidence_pb2 as _confidence_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Ball(_message.Message):
    __slots__ = ["center", "confidence"]
    CENTER_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    center: _point_pb2.Point
    confidence: _confidence_pb2.Confidence
    def __init__(self, center: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., confidence: _Optional[_Union[_confidence_pb2.Confidence, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/srv/get_state_validity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraint_eval_result_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_constraint__eval__result__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraints_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_constraints__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import contact_information_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_contact__information__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import cost_source_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_cost__source__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/moveit_msgs/srv/get_state_validity.proto\x12+make87_messages_ros2.humble.moveit_msgs.srv\x1a!make87_messages/core/header.proto\x1aHmake87_messages_ros2/humble/moveit_msgs/msg/constraint_eval_result.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/constraints.proto\x1a\x45make87_messages_ros2/humble/moveit_msgs/msg/contact_information.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/cost_source.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/robot_state.proto\"\xf8\x01\n\x17GetStateValidityRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12L\n\x0brobot_state\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12\x12\n\ngroup_name\x18\x03 \x01(\t\x12M\n\x0b\x63onstraints\x18\x04 \x01(\x0b\x32\x38.make87_messages_ros2.humble.moveit_msgs.msg.Constraints\"\xd7\x02\n\x18GetStateValidityResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05valid\x18\x02 \x01(\x08\x12Q\n\x08\x63ontacts\x18\x03 \x03(\x0b\x32?.make87_messages_ros2.humble.moveit_msgs.msg.ContactInformation\x12M\n\x0c\x63ost_sources\x18\x04 \x03(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.CostSource\x12\\\n\x11\x63onstraint_result\x18\x05 \x03(\x0b\x32\x41.make87_messages_ros2.humble.moveit_msgs.msg.ConstraintEvalResultb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.srv.get_state_validity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETSTATEVALIDITYREQUEST']._serialized_start=487
  _globals['_GETSTATEVALIDITYREQUEST']._serialized_end=735
  _globals['_GETSTATEVALIDITYRESPONSE']._serialized_start=738
  _globals['_GETSTATEVALIDITYRESPONSE']._serialized_end=1081
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DispenserRequestItem(_message.Message):
    __slots__ = ["type_guid", "quantity", "compartment_name"]
    TYPE_GUID_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    COMPARTMENT_NAME_FIELD_NUMBER: _ClassVar[int]
    type_guid: str
    quantity: int
    compartment_name: str
    def __init__(self, type_guid: _Optional[str] = ..., quantity: _Optional[int] = ..., compartment_name: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.ros_gz_interfaces.msg import world_reset_pb2 as _world_reset_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WorldControl(_message.Message):
    __slots__ = ["pause", "step", "multi_step", "reset", "seed", "run_to_sim_time"]
    PAUSE_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    MULTI_STEP_FIELD_NUMBER: _ClassVar[int]
    RESET_FIELD_NUMBER: _ClassVar[int]
    SEED_FIELD_NUMBER: _ClassVar[int]
    RUN_TO_SIM_TIME_FIELD_NUMBER: _ClassVar[int]
    pause: bool
    step: bool
    multi_step: int
    reset: _world_reset_pb2.WorldReset
    seed: int
    run_to_sim_time: _time_pb2.Time
    def __init__(self, pause: bool = ..., step: bool = ..., multi_step: _Optional[int] = ..., reset: _Optional[_Union[_world_reset_pb2.WorldReset, _Mapping]] = ..., seed: _Optional[int] = ..., run_to_sim_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg import field_information_pb2 as _field_information_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FieldInformationArray(_message.Message):
    __slots__ = ["header", "fields"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    fields: _containers.RepeatedCompositeFieldContainer[_field_information_pb2.FieldInformation]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., fields: _Optional[_Iterable[_Union[_field_information_pb2.FieldInformation, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_queries.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_identity_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__identity__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_query_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_queries.proto\x12\x30make87_messages_ros2.humble.rmf_traffic_msgs.msg\x1a!make87_messages/core/header.proto\x1aHmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_identity.proto\x1a\x45make87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query.proto\"\xf9\x01\n\x0fScheduleQueries\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12S\n\x07node_id\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleIdentity\x12P\n\x07queries\x18\x03 \x03(\x0b\x32?.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleQuery\x12\x11\n\tquery_ids\x18\x04 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_traffic_msgs.msg.schedule_queries_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCHEDULEQUERIES']._serialized_start=306
  _globals['_SCHEDULEQUERIES']._serialized_end=555
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as _point_cloud2_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetPointmapLayerRequest(_message.Message):
    __slots__ = ["layer_name"]
    LAYER_NAME_FIELD_NUMBER: _ClassVar[int]
    layer_name: str
    def __init__(self, layer_name: _Optional[str] = ...) -> None: ...

class GetPointmapLayerResponse(_message.Message):
    __slots__ = ["valid", "points"]
    VALID_FIELD_NUMBER: _ClassVar[int]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    valid: bool
    points: _point_cloud2_pb2.PointCloud2
    def __init__(self, valid: bool = ..., points: _Optional[_Union[_point_cloud2_pb2.PointCloud2, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/visualization_msgs/msg/interactive_marker_control.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_quaternion__pb2
from make87_messages_ros2.humble.visualization_msgs.msg import marker_pb2 as make87__messages__ros2_dot_humble_dot_visualization__msgs_dot_msg_dot_marker__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/humble/visualization_msgs/msg/interactive_marker_control.proto\x12\x32make87_messages_ros2.humble.visualization_msgs.msg\x1a!make87_messages/core/header.proto\x1a>make87_messages_ros2/humble/geometry_msgs/msg/quaternion.proto\x1a?make87_messages_ros2/humble/visualization_msgs/msg/marker.proto\"\xfc\x02\n\x18InteractiveMarkerControl\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\x0borientation\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.humble.geometry_msgs.msg.Quaternion\x12\x18\n\x10orientation_mode\x18\x04 \x01(\r\x12\x18\n\x10interaction_mode\x18\x05 \x01(\r\x12\x16\n\x0e\x61lways_visible\x18\x06 \x01(\x08\x12K\n\x07markers\x18\x07 \x03(\x0b\x32:.make87_messages_ros2.humble.visualization_msgs.msg.Marker\x12&\n\x1eindependent_marker_orientation\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.visualization_msgs.msg.interactive_marker_control_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INTERACTIVEMARKERCONTROL']._serialized_start=304
  _globals['_INTERACTIVEMARKERCONTROL']._serialized_end=684
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geographic_msgs.msg import route_path_pb2 as _route_path_pb2
from make87_messages_ros2.humble.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetRoutePlanRequest(_message.Message):
    __slots__ = ["header", "network", "start", "goal"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NETWORK_FIELD_NUMBER: _ClassVar[int]
    START_FIELD_NUMBER: _ClassVar[int]
    GOAL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    network: _uuid_pb2.UUID
    start: _uuid_pb2.UUID
    goal: _uuid_pb2.UUID
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., network: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., start: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., goal: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ...) -> None: ...

class GetRoutePlanResponse(_message.Message):
    __slots__ = ["header", "success", "status", "plan"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    status: str
    plan: _route_path_pb2.RoutePath
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., status: _Optional[str] = ..., plan: _Optional[_Union[_route_path_pb2.RoutePath, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RxmSFRBX(_message.Message):
    __slots__ = ["header", "gnss_id", "sv_id", "reserved0", "freq_id", "num_words", "chn", "version", "reserved1", "dwrd"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GNSS_ID_FIELD_NUMBER: _ClassVar[int]
    SV_ID_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    FREQ_ID_FIELD_NUMBER: _ClassVar[int]
    NUM_WORDS_FIELD_NUMBER: _ClassVar[int]
    CHN_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    DWRD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    gnss_id: int
    sv_id: int
    reserved0: int
    freq_id: int
    num_words: int
    chn: int
    version: int
    reserved1: int
    dwrd: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., gnss_id: _Optional[int] = ..., sv_id: _Optional[int] = ..., reserved0: _Optional[int] = ..., freq_id: _Optional[int] = ..., num_words: _Optional[int] = ..., chn: _Optional[int] = ..., version: _Optional[int] = ..., reserved1: _Optional[int] = ..., dwrd: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import joint_trajectory_pb2 as _joint_trajectory_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetJointTrajectoryRequest(_message.Message):
    __slots__ = ["model_name", "joint_trajectory", "model_pose", "set_model_pose", "disable_physics_updates"]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    JOINT_TRAJECTORY_FIELD_NUMBER: _ClassVar[int]
    MODEL_POSE_FIELD_NUMBER: _ClassVar[int]
    SET_MODEL_POSE_FIELD_NUMBER: _ClassVar[int]
    DISABLE_PHYSICS_UPDATES_FIELD_NUMBER: _ClassVar[int]
    model_name: str
    joint_trajectory: _joint_trajectory_pb2.JointTrajectory
    model_pose: _pose_pb2.Pose
    set_model_pose: bool
    disable_physics_updates: bool
    def __init__(self, model_name: _Optional[str] = ..., joint_trajectory: _Optional[_Union[_joint_trajectory_pb2.JointTrajectory, _Mapping]] = ..., model_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., set_model_pose: bool = ..., disable_physics_updates: bool = ...) -> None: ...

class SetJointTrajectoryResponse(_message.Message):
    __slots__ = ["success", "status_message"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    status_message: str
    def __init__(self, success: bool = ..., status_message: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import negotiation_key_pb2 as _negotiation_key_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NegotiationConclusion(_message.Message):
    __slots__ = ["header", "conflict_version", "resolved", "table"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONFLICT_VERSION_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    conflict_version: int
    resolved: bool
    table: _containers.RepeatedCompositeFieldContainer[_negotiation_key_pb2.NegotiationKey]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., conflict_version: _Optional[int] = ..., resolved: bool = ..., table: _Optional[_Iterable[_Union[_negotiation_key_pb2.NegotiationKey, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DataHeader(_message.Message):
    __slots__ = ["header", "version_version", "version_major_version", "version_minor_version", "version_release", "serial_number_of_device", "serial_number_of_channel_plug", "channel_number", "sequence_number", "scan_number", "timestamp_date", "timestamp_time"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_VERSION_FIELD_NUMBER: _ClassVar[int]
    VERSION_MAJOR_VERSION_FIELD_NUMBER: _ClassVar[int]
    VERSION_MINOR_VERSION_FIELD_NUMBER: _ClassVar[int]
    VERSION_RELEASE_FIELD_NUMBER: _ClassVar[int]
    SERIAL_NUMBER_OF_DEVICE_FIELD_NUMBER: _ClassVar[int]
    SERIAL_NUMBER_OF_CHANNEL_PLUG_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SCAN_NUMBER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_DATE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_TIME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    version_version: int
    version_major_version: int
    version_minor_version: int
    version_release: int
    serial_number_of_device: int
    serial_number_of_channel_plug: int
    channel_number: int
    sequence_number: int
    scan_number: int
    timestamp_date: int
    timestamp_time: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., version_version: _Optional[int] = ..., version_major_version: _Optional[int] = ..., version_minor_version: _Optional[int] = ..., version_release: _Optional[int] = ..., serial_number_of_device: _Optional[int] = ..., serial_number_of_channel_plug: _Optional[int] = ..., channel_number: _Optional[int] = ..., sequence_number: _Optional[int] = ..., scan_number: _Optional[int] = ..., timestamp_date: _Optional[int] = ..., timestamp_time: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/std_msgs/msg/u_int16_multi_array.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import multi_array_layout_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_multi__array__layout__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/std_msgs/msg/u_int16_multi_array.proto\x12\'make87_messages_ros2.jazzy.std_msgs.msg\x1a@make87_messages_ros2/jazzy/std_msgs/msg/multi_array_layout.proto\"k\n\x10UInt16MultiArray\x12I\n\x06layout\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.std_msgs.msg.MultiArrayLayout\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.std_msgs.msg.u_int16_multi_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UINT16MULTIARRAY']._serialized_start=176
  _globals['_UINT16MULTIARRAY']._serialized_end=283
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PointField(_message.Message):
    __slots__ = ["name", "offset", "datatype", "count"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    DATATYPE_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    name: str
    offset: int
    datatype: int
    count: int
    def __init__(self, name: _Optional[str] = ..., offset: _Optional[int] = ..., datatype: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ColaMsgSrvRequest(_message.Message):
    __slots__ = ["request"]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    request: str
    def __init__(self, request: _Optional[str] = ...) -> None: ...

class ColaMsgSrvResponse(_message.Message):
    __slots__ = ["response"]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    response: str
    def __init__(self, response: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TestMessage(_message.Message):
    __slots__ = ["header", "b", "ui8", "ui16", "ui32", "ui64", "i8", "i16", "i32", "i64", "f32", "f64", "str", "bounded_str", "t", "d", "point_arr"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    B_FIELD_NUMBER: _ClassVar[int]
    UI8_FIELD_NUMBER: _ClassVar[int]
    UI16_FIELD_NUMBER: _ClassVar[int]
    UI32_FIELD_NUMBER: _ClassVar[int]
    UI64_FIELD_NUMBER: _ClassVar[int]
    I8_FIELD_NUMBER: _ClassVar[int]
    I16_FIELD_NUMBER: _ClassVar[int]
    I32_FIELD_NUMBER: _ClassVar[int]
    I64_FIELD_NUMBER: _ClassVar[int]
    F32_FIELD_NUMBER: _ClassVar[int]
    F64_FIELD_NUMBER: _ClassVar[int]
    STR_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_STR_FIELD_NUMBER: _ClassVar[int]
    T_FIELD_NUMBER: _ClassVar[int]
    D_FIELD_NUMBER: _ClassVar[int]
    POINT_ARR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    b: bool
    ui8: int
    ui16: int
    ui32: int
    ui64: int
    i8: int
    i16: int
    i32: int
    i64: int
    f32: float
    f64: float
    str: str
    bounded_str: str
    t: _time_pb2.Time
    d: _duration_pb2.Duration
    point_arr: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., b: bool = ..., ui8: _Optional[int] = ..., ui16: _Optional[int] = ..., ui32: _Optional[int] = ..., ui64: _Optional[int] = ..., i8: _Optional[int] = ..., i16: _Optional[int] = ..., i32: _Optional[int] = ..., i64: _Optional[int] = ..., f32: _Optional[float] = ..., f64: _Optional[float] = ..., str: _Optional[str] = ..., bounded_str: _Optional[str] = ..., t: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., d: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., point_arr: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Param(_message.Message):
    __slots__ = ["name", "type", "sub_types"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SUB_TYPES_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    sub_types: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., sub_types: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/tuw_object_map_msgs/msg/object.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.rolling.tuw_object_map_msgs.msg import geo_point_pb2 as make87__messages__ros2_dot_rolling_dot_tuw__object__map__msgs_dot_msg_dot_geo__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/tuw_object_map_msgs/msg/object.proto\x12\x34make87_messages_ros2.rolling.tuw_object_map_msgs.msg\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/point.proto\x1a\x44make87_messages_ros2/rolling/tuw_object_map_msgs/msg/geo_point.proto\"\xf3\x01\n\x06Object\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\r\x12R\n\ngeo_points\x18\x03 \x03(\x0b\x32>.make87_messages_ros2.rolling.tuw_object_map_msgs.msg.GeoPoint\x12I\n\nmap_points\x18\x04 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Point\x12\x18\n\x10\x65nflation_radius\x18\x05 \x03(\x01\x12\x16\n\x0e\x62ondary_radius\x18\x06 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.tuw_object_map_msgs.msg.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECT']._serialized_start=254
  _globals['_OBJECT']._serialized_end=497
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import location_pb2 as _location_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PathRequest(_message.Message):
    __slots__ = ["fleet_name", "robot_name", "path", "task_id"]
    FLEET_NAME_FIELD_NUMBER: _ClassVar[int]
    ROBOT_NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    fleet_name: str
    robot_name: str
    path: _containers.RepeatedCompositeFieldContainer[_location_pb2.Location]
    task_id: str
    def __init__(self, fleet_name: _Optional[str] = ..., robot_name: _Optional[str] = ..., path: _Optional[_Iterable[_Union[_location_pb2.Location, _Mapping]]] = ..., task_id: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.ros_gz_interfaces.msg import world_control_pb2 as _world_control_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ControlWorldRequest(_message.Message):
    __slots__ = ["header", "world_control"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    WORLD_CONTROL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    world_control: _world_control_pb2.WorldControl
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., world_control: _Optional[_Union[_world_control_pb2.WorldControl, _Mapping]] = ...) -> None: ...

class ControlWorldResponse(_message.Message):
    __slots__ = ["header", "success"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import object_color_pb2 as _object_color_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as _robot_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DisplayRobotState(_message.Message):
    __slots__ = ["header", "state", "highlight_links", "hide"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    HIGHLIGHT_LINKS_FIELD_NUMBER: _ClassVar[int]
    HIDE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    state: _robot_state_pb2.RobotState
    highlight_links: _containers.RepeatedCompositeFieldContainer[_object_color_pb2.ObjectColor]
    hide: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., state: _Optional[_Union[_robot_state_pb2.RobotState, _Mapping]] = ..., highlight_links: _Optional[_Iterable[_Union[_object_color_pb2.ObjectColor, _Mapping]]] = ..., hide: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/canopen_interfaces/srv/co_nmt_id.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/humble/canopen_interfaces/srv/co_nmt_id.proto\x12\x32make87_messages_ros2.humble.canopen_interfaces.srv\x1a!make87_messages/core/header.proto\"b\n\x0e\x43ONmtIDRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\nnmtcommand\x18\x02 \x01(\r\x12\x0e\n\x06nodeid\x18\x03 \x01(\r\"P\n\x0f\x43ONmtIDResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.canopen_interfaces.srv.co_nmt_id_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONMTIDREQUEST']._serialized_start=157
  _globals['_CONMTIDREQUEST']._serialized_end=255
  _globals['_CONMTIDRESPONSE']._serialized_start=257
  _globals['_CONMTIDRESPONSE']._serialized_end=337
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ToggleFilterProcessingRequest(_message.Message):
    __slots__ = ["on"]
    ON_FIELD_NUMBER: _ClassVar[int]
    on: bool
    def __init__(self, on: bool = ...) -> None: ...

class ToggleFilterProcessingResponse(_message.Message):
    __slots__ = ["status"]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: bool
    def __init__(self, status: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sbg_driver/msg/sbg_gps_hdt.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/jazzy/sbg_driver/msg/sbg_gps_hdt.proto\x12)make87_messages_ros2.jazzy.sbg_driver.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x8e\x02\n\tSbgGpsHdt\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x12\n\ntime_stamp\x18\x02 \x01(\r\x12\x0e\n\x06status\x18\x03 \x01(\r\x12\x0b\n\x03tow\x18\x04 \x01(\r\x12\x14\n\x0ctrue_heading\x18\x05 \x01(\x02\x12\x18\n\x10true_heading_acc\x18\x06 \x01(\x02\x12\r\n\x05pitch\x18\x07 \x01(\x02\x12\x11\n\tpitch_acc\x18\x08 \x01(\x02\x12\x10\n\x08\x62\x61seline\x18\t \x01(\x02\x12\x16\n\x0enum_sv_tracked\x18\n \x01(\r\x12\x13\n\x0bnum_sv_used\x18\x0b \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sbg_driver.msg.sbg_gps_hdt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SBGGPSHDT']._serialized_start=161
  _globals['_SBGGPSHDT']._serialized_end=431
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NovatelReceiverStatus(_message.Message):
    __slots__ = ["original_status_code", "error_flag", "temperature_flag", "voltage_supply_flag", "antenna_powered", "antenna_is_open", "antenna_is_shorted", "cpu_overload_flag", "com1_buffer_overrun", "com2_buffer_overrun", "com3_buffer_overrun", "usb_buffer_overrun", "rf1_agc_flag", "rf2_agc_flag", "almanac_flag", "position_solution_flag", "position_fixed_flag", "clock_steering_status_enabled", "clock_model_flag", "oemv_external_oscillator_flag", "software_resource_flag", "aux1_status_event_flag", "aux2_status_event_flag", "aux3_status_event_flag"]
    ORIGINAL_STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FLAG_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FLAG_FIELD_NUMBER: _ClassVar[int]
    VOLTAGE_SUPPLY_FLAG_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_POWERED_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_IS_OPEN_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_IS_SHORTED_FIELD_NUMBER: _ClassVar[int]
    CPU_OVERLOAD_FLAG_FIELD_NUMBER: _ClassVar[int]
    COM1_BUFFER_OVERRUN_FIELD_NUMBER: _ClassVar[int]
    COM2_BUFFER_OVERRUN_FIELD_NUMBER: _ClassVar[int]
    COM3_BUFFER_OVERRUN_FIELD_NUMBER: _ClassVar[int]
    USB_BUFFER_OVERRUN_FIELD_NUMBER: _ClassVar[int]
    RF1_AGC_FLAG_FIELD_NUMBER: _ClassVar[int]
    RF2_AGC_FLAG_FIELD_NUMBER: _ClassVar[int]
    ALMANAC_FLAG_FIELD_NUMBER: _ClassVar[int]
    POSITION_SOLUTION_FLAG_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIXED_FLAG_FIELD_NUMBER: _ClassVar[int]
    CLOCK_STEERING_STATUS_ENABLED_FIELD_NUMBER: _ClassVar[int]
    CLOCK_MODEL_FLAG_FIELD_NUMBER: _ClassVar[int]
    OEMV_EXTERNAL_OSCILLATOR_FLAG_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_RESOURCE_FLAG_FIELD_NUMBER: _ClassVar[int]
    AUX1_STATUS_EVENT_FLAG_FIELD_NUMBER: _ClassVar[int]
    AUX2_STATUS_EVENT_FLAG_FIELD_NUMBER: _ClassVar[int]
    AUX3_STATUS_EVENT_FLAG_FIELD_NUMBER: _ClassVar[int]
    original_status_code: int
    error_flag: bool
    temperature_flag: bool
    voltage_supply_flag: bool
    antenna_powered: bool
    antenna_is_open: bool
    antenna_is_shorted: bool
    cpu_overload_flag: bool
    com1_buffer_overrun: bool
    com2_buffer_overrun: bool
    com3_buffer_overrun: bool
    usb_buffer_overrun: bool
    rf1_agc_flag: bool
    rf2_agc_flag: bool
    almanac_flag: bool
    position_solution_flag: bool
    position_fixed_flag: bool
    clock_steering_status_enabled: bool
    clock_model_flag: bool
    oemv_external_oscillator_flag: bool
    software_resource_flag: bool
    aux1_status_event_flag: bool
    aux2_status_event_flag: bool
    aux3_status_event_flag: bool
    def __init__(self, original_status_code: _Optional[int] = ..., error_flag: bool = ..., temperature_flag: bool = ..., voltage_supply_flag: bool = ..., antenna_powered: bool = ..., antenna_is_open: bool = ..., antenna_is_shorted: bool = ..., cpu_overload_flag: bool = ..., com1_buffer_overrun: bool = ..., com2_buffer_overrun: bool = ..., com3_buffer_overrun: bool = ..., usb_buffer_overrun: bool = ..., rf1_agc_flag: bool = ..., rf2_agc_flag: bool = ..., almanac_flag: bool = ..., position_solution_flag: bool = ..., position_fixed_flag: bool = ..., clock_steering_status_enabled: bool = ..., clock_model_flag: bool = ..., oemv_external_oscillator_flag: bool = ..., software_resource_flag: bool = ..., aux1_status_event_flag: bool = ..., aux2_status_event_flag: bool = ..., aux3_status_event_flag: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CfgNAVX5(_message.Message):
    __slots__ = ["header", "version", "mask1", "mask2", "reserved1", "min_svs", "max_svs", "min_cno", "reserved2", "ini_fix3d", "reserved3", "ack_aiding", "wkn_rollover", "sig_atten_comp_mode", "reserved4", "use_ppp", "aop_cfg", "reserved5", "aop_orb_max_err", "reserved6", "use_adr"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    MASK1_FIELD_NUMBER: _ClassVar[int]
    MASK2_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    MIN_SVS_FIELD_NUMBER: _ClassVar[int]
    MAX_SVS_FIELD_NUMBER: _ClassVar[int]
    MIN_CNO_FIELD_NUMBER: _ClassVar[int]
    RESERVED2_FIELD_NUMBER: _ClassVar[int]
    INI_FIX3D_FIELD_NUMBER: _ClassVar[int]
    RESERVED3_FIELD_NUMBER: _ClassVar[int]
    ACK_AIDING_FIELD_NUMBER: _ClassVar[int]
    WKN_ROLLOVER_FIELD_NUMBER: _ClassVar[int]
    SIG_ATTEN_COMP_MODE_FIELD_NUMBER: _ClassVar[int]
    RESERVED4_FIELD_NUMBER: _ClassVar[int]
    USE_PPP_FIELD_NUMBER: _ClassVar[int]
    AOP_CFG_FIELD_NUMBER: _ClassVar[int]
    RESERVED5_FIELD_NUMBER: _ClassVar[int]
    AOP_ORB_MAX_ERR_FIELD_NUMBER: _ClassVar[int]
    RESERVED6_FIELD_NUMBER: _ClassVar[int]
    USE_ADR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    version: int
    mask1: int
    mask2: int
    reserved1: _containers.RepeatedScalarFieldContainer[int]
    min_svs: int
    max_svs: int
    min_cno: int
    reserved2: int
    ini_fix3d: int
    reserved3: _containers.RepeatedScalarFieldContainer[int]
    ack_aiding: int
    wkn_rollover: int
    sig_atten_comp_mode: int
    reserved4: _containers.RepeatedScalarFieldContainer[int]
    use_ppp: int
    aop_cfg: int
    reserved5: _containers.RepeatedScalarFieldContainer[int]
    aop_orb_max_err: int
    reserved6: _containers.RepeatedScalarFieldContainer[int]
    use_adr: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., version: _Optional[int] = ..., mask1: _Optional[int] = ..., mask2: _Optional[int] = ..., reserved1: _Optional[_Iterable[int]] = ..., min_svs: _Optional[int] = ..., max_svs: _Optional[int] = ..., min_cno: _Optional[int] = ..., reserved2: _Optional[int] = ..., ini_fix3d: _Optional[int] = ..., reserved3: _Optional[_Iterable[int]] = ..., ack_aiding: _Optional[int] = ..., wkn_rollover: _Optional[int] = ..., sig_atten_comp_mode: _Optional[int] = ..., reserved4: _Optional[_Iterable[int]] = ..., use_ppp: _Optional[int] = ..., aop_cfg: _Optional[int] = ..., reserved5: _Optional[_Iterable[int]] = ..., aop_orb_max_err: _Optional[int] = ..., reserved6: _Optional[_Iterable[int]] = ..., use_adr: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/septentrio_gnss_driver/msg/ins_nav_cart.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.septentrio_gnss_driver.msg import block_header_pb2 as make87__messages__ros2_dot_humble_dot_septentrio__gnss__driver_dot_msg_dot_block__header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/septentrio_gnss_driver/msg/ins_nav_cart.proto\x12\x36make87_messages_ros2.humble.septentrio_gnss_driver.msg\x1a!make87_messages/core/header.proto\x1aImake87_messages_ros2/humble/septentrio_gnss_driver/msg/block_header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xc5\x06\n\nINSNavCart\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12Y\n\x0c\x62lock_header\x18\x03 \x01(\x0b\x32\x43.make87_messages_ros2.humble.septentrio_gnss_driver.msg.BlockHeader\x12\x11\n\tgnss_mode\x18\x04 \x01(\r\x12\r\n\x05\x65rror\x18\x05 \x01(\r\x12\x0c\n\x04info\x18\x06 \x01(\r\x12\x10\n\x08gnss_age\x18\x07 \x01(\r\x12\t\n\x01x\x18\x08 \x01(\x01\x12\t\n\x01y\x18\t \x01(\x01\x12\t\n\x01z\x18\n \x01(\x01\x12\x10\n\x08\x61\x63\x63uracy\x18\x0b \x01(\r\x12\x0f\n\x07latency\x18\x0c \x01(\r\x12\r\n\x05\x64\x61tum\x18\r \x01(\r\x12\x0f\n\x07sb_list\x18\x0e \x01(\r\x12\x11\n\tx_std_dev\x18\x0f \x01(\x02\x12\x11\n\ty_std_dev\x18\x10 \x01(\x02\x12\x11\n\tz_std_dev\x18\x11 \x01(\x02\x12\x0e\n\x06xy_cov\x18\x12 \x01(\x02\x12\x0e\n\x06xz_cov\x18\x13 \x01(\x02\x12\x0e\n\x06yz_cov\x18\x14 \x01(\x02\x12\x0f\n\x07heading\x18\x15 \x01(\x02\x12\r\n\x05pitch\x18\x16 \x01(\x02\x12\x0c\n\x04roll\x18\x17 \x01(\x02\x12\x17\n\x0fheading_std_dev\x18\x18 \x01(\x02\x12\x15\n\rpitch_std_dev\x18\x19 \x01(\x02\x12\x14\n\x0croll_std_dev\x18\x1a \x01(\x02\x12\x19\n\x11heading_pitch_cov\x18\x1b \x01(\x02\x12\x18\n\x10heading_roll_cov\x18\x1c \x01(\x02\x12\x16\n\x0epitch_roll_cov\x18\x1d \x01(\x02\x12\n\n\x02vx\x18\x1e \x01(\x02\x12\n\n\x02vy\x18\x1f \x01(\x02\x12\n\n\x02vz\x18  \x01(\x02\x12\x12\n\nvx_std_dev\x18! \x01(\x02\x12\x12\n\nvy_std_dev\x18\" \x01(\x02\x12\x12\n\nvz_std_dev\x18# \x01(\x02\x12\x11\n\tvx_vy_cov\x18$ \x01(\x02\x12\x11\n\tvx_vz_cov\x18% \x01(\x02\x12\x11\n\tvy_vz_cov\x18& \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.septentrio_gnss_driver.msg.ins_nav_cart_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INSNAVCART']._serialized_start=299
  _globals['_INSNAVCART']._serialized_end=1136
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mola_msgs/srv/map_load.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/jazzy/mola_msgs/srv/map_load.proto\x12(make87_messages_ros2.jazzy.mola_msgs.srv\"\"\n\x0eMapLoadRequest\x12\x10\n\x08map_path\x18\x01 \x01(\t\"9\n\x0fMapLoadResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mola_msgs.srv.map_load_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MAPLOADREQUEST']._serialized_start=101
  _globals['_MAPLOADREQUEST']._serialized_end=135
  _globals['_MAPLOADRESPONSE']._serialized_start=137
  _globals['_MAPLOADRESPONSE']._serialized_end=194
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/robot_controllers_msgs/msg/diff_drive_limiter_params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVmake87_messages_ros2/humble/robot_controllers_msgs/msg/diff_drive_limiter_params.proto\x12\x36make87_messages_ros2.humble.robot_controllers_msgs.msg\x1a!make87_messages/core/header.proto\"\xce\x02\n\x16\x44iffDriveLimiterParams\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x1b\n\x13max_linear_velocity\x18\x02 \x01(\x01\x12\x1f\n\x17max_linear_acceleration\x18\x03 \x01(\x01\x12\x1c\n\x14max_angular_velocity\x18\x04 \x01(\x01\x12 \n\x18max_angular_acceleration\x18\x05 \x01(\x01\x12\x1a\n\x12max_wheel_velocity\x18\x06 \x01(\x01\x12\x13\n\x0btrack_width\x18\x07 \x01(\x01\x12/\n\'angular_velocity_limits_linear_velocity\x18\x08 \x01(\x08\x12&\n\x1escale_to_wheel_velocity_limits\x18\t \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.robot_controllers_msgs.msg.diff_drive_limiter_params_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DIFFDRIVELIMITERPARAMS']._serialized_start=182
  _globals['_DIFFDRIVELIMITERPARAMS']._serialized_end=516
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/msg/override_rc_in.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/mavros_msgs/msg/override_rc_in.proto\x12,make87_messages_ros2.rolling.mavros_msgs.msg\" \n\x0cOverrideRCIn\x12\x10\n\x08\x63hannels\x18\x01 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.msg.override_rc_in_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OVERRIDERCIN']._serialized_start=115
  _globals['_OVERRIDERCIN']._serialized_end=147
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/flexbe_msgs/msg/container_structure.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.flexbe_msgs.msg import container_pb2 as make87__messages__ros2_dot_rolling_dot_flexbe__msgs_dot_msg_dot_container__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/flexbe_msgs/msg/container_structure.proto\x12,make87_messages_ros2.rolling.flexbe_msgs.msg\x1a<make87_messages_ros2/rolling/flexbe_msgs/msg/container.proto\"v\n\x12\x43ontainerStructure\x12\x13\n\x0b\x62\x65havior_id\x18\x01 \x01(\x05\x12K\n\ncontainers\x18\x02 \x03(\x0b\x32\x37.make87_messages_ros2.rolling.flexbe_msgs.msg.Containerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.flexbe_msgs.msg.container_structure_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONTAINERSTRUCTURE']._serialized_start=182
  _globals['_CONTAINERSTRUCTURE']._serialized_end=300
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/robot_calibration_msgs/msg/calibration_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.robot_calibration_msgs.msg import observation_pb2 as make87__messages__ros2_dot_jazzy_dot_robot__calibration__msgs_dot_msg_dot_observation__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import joint_state_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_joint__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/jazzy/robot_calibration_msgs/msg/calibration_data.proto\x12\x35make87_messages_ros2.jazzy.robot_calibration_msgs.msg\x1aGmake87_messages_ros2/jazzy/robot_calibration_msgs/msg/observation.proto\x1a<make87_messages_ros2/jazzy/sensor_msgs/msg/joint_state.proto\"\xb9\x01\n\x0f\x43\x61librationData\x12L\n\x0cjoint_states\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.sensor_msgs.msg.JointState\x12X\n\x0cobservations\x18\x02 \x03(\x0b\x32\x42.make87_messages_ros2.jazzy.robot_calibration_msgs.msg.Observationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.robot_calibration_msgs.msg.calibration_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CALIBRATIONDATA']._serialized_start=271
  _globals['_CALIBRATIONDATA']._serialized_end=456
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Lane(_message.Message):
    __slots__ = ["header", "lane_curvature", "lane_heading", "construction_area", "pitch_angle", "yaw_angle", "right_ldw_availability", "left_ldw_availability"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LANE_CURVATURE_FIELD_NUMBER: _ClassVar[int]
    LANE_HEADING_FIELD_NUMBER: _ClassVar[int]
    CONSTRUCTION_AREA_FIELD_NUMBER: _ClassVar[int]
    PITCH_ANGLE_FIELD_NUMBER: _ClassVar[int]
    YAW_ANGLE_FIELD_NUMBER: _ClassVar[int]
    RIGHT_LDW_AVAILABILITY_FIELD_NUMBER: _ClassVar[int]
    LEFT_LDW_AVAILABILITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    lane_curvature: float
    lane_heading: float
    construction_area: bool
    pitch_angle: float
    yaw_angle: float
    right_ldw_availability: bool
    left_ldw_availability: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., lane_curvature: _Optional[float] = ..., lane_heading: _Optional[float] = ..., construction_area: bool = ..., pitch_angle: _Optional[float] = ..., yaw_angle: _Optional[float] = ..., right_ldw_availability: bool = ..., left_ldw_availability: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Wrench(_message.Message):
    __slots__ = ["force", "torque"]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    TORQUE_FIELD_NUMBER: _ClassVar[int]
    force: _vector3_pb2.Vector3
    torque: _vector3_pb2.Vector3
    def __init__(self, force: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., torque: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/msg/planning_scene_world.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import collision_object_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_collision__object__pb2
from make87_messages_ros2.humble.octomap_msgs.msg import octomap_with_pose_pb2 as make87__messages__ros2_dot_humble_dot_octomap__msgs_dot_msg_dot_octomap__with__pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/moveit_msgs/msg/planning_scene_world.proto\x12+make87_messages_ros2.humble.moveit_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x42make87_messages_ros2/humble/moveit_msgs/msg/collision_object.proto\x1a\x44make87_messages_ros2/humble/octomap_msgs/msg/octomap_with_pose.proto\"\xeb\x01\n\x12PlanningSceneWorld\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12W\n\x11\x63ollision_objects\x18\x02 \x03(\x0b\x32<.make87_messages_ros2.humble.moveit_msgs.msg.CollisionObject\x12N\n\x07octomap\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.humble.octomap_msgs.msg.OctomapWithPoseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.msg.planning_scene_world_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLANNINGSCENEWORLD']._serialized_start=293
  _globals['_PLANNINGSCENEWORLD']._serialized_end=528
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Metadata(_message.Message):
    __slots__ = ["header", "hostname", "lidar_mode", "timestamp_mode", "beam_azimuth_angles", "beam_altitude_angles", "imu_to_sensor_transform", "lidar_to_sensor_transform", "serial_no", "firmware_rev", "imu_port", "lidar_port"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    LIDAR_MODE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_MODE_FIELD_NUMBER: _ClassVar[int]
    BEAM_AZIMUTH_ANGLES_FIELD_NUMBER: _ClassVar[int]
    BEAM_ALTITUDE_ANGLES_FIELD_NUMBER: _ClassVar[int]
    IMU_TO_SENSOR_TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    LIDAR_TO_SENSOR_TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    SERIAL_NO_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_REV_FIELD_NUMBER: _ClassVar[int]
    IMU_PORT_FIELD_NUMBER: _ClassVar[int]
    LIDAR_PORT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    hostname: str
    lidar_mode: str
    timestamp_mode: str
    beam_azimuth_angles: _containers.RepeatedScalarFieldContainer[float]
    beam_altitude_angles: _containers.RepeatedScalarFieldContainer[float]
    imu_to_sensor_transform: _containers.RepeatedScalarFieldContainer[float]
    lidar_to_sensor_transform: _containers.RepeatedScalarFieldContainer[float]
    serial_no: str
    firmware_rev: str
    imu_port: int
    lidar_port: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., hostname: _Optional[str] = ..., lidar_mode: _Optional[str] = ..., timestamp_mode: _Optional[str] = ..., beam_azimuth_angles: _Optional[_Iterable[float]] = ..., beam_altitude_angles: _Optional[_Iterable[float]] = ..., imu_to_sensor_transform: _Optional[_Iterable[float]] = ..., lidar_to_sensor_transform: _Optional[_Iterable[float]] = ..., serial_no: _Optional[str] = ..., firmware_rev: _Optional[str] = ..., imu_port: _Optional[int] = ..., lidar_port: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_change_add_item_pb2 as _schedule_change_add_item_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduleChangeAdd(_message.Message):
    __slots__ = ["plan_id", "items"]
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    plan_id: int
    items: _containers.RepeatedCompositeFieldContainer[_schedule_change_add_item_pb2.ScheduleChangeAddItem]
    def __init__(self, plan_id: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_schedule_change_add_item_pb2.ScheduleChangeAddItem, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_change_progress.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_change_progress.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\"T\n\x16ScheduleChangeProgress\x12\x14\n\x0chas_progress\x18\x01 \x01(\x08\x12\x0f\n\x07version\x18\x02 \x01(\x04\x12\x13\n\x0b\x63heckpoints\x18\x03 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.schedule_change_progress_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCHEDULECHANGEPROGRESS']._serialized_start=135
  _globals['_SCHEDULECHANGEPROGRESS']._serialized_end=219
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LeadVehicle(_message.Message):
    __slots__ = ["header", "ros2_header", "headway_distance", "speed", "heading", "x_pos", "y_pos", "classification", "type"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    HEADWAY_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    X_POS_FIELD_NUMBER: _ClassVar[int]
    Y_POS_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    headway_distance: float
    speed: float
    heading: float
    x_pos: float
    y_pos: float
    classification: int
    type: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., headway_distance: _Optional[float] = ..., speed: _Optional[float] = ..., heading: _Optional[float] = ..., x_pos: _Optional[float] = ..., y_pos: _Optional[float] = ..., classification: _Optional[int] = ..., type: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ADSBVehicle(_message.Message):
    __slots__ = ["header", "icao_address", "callsign", "latitude", "longitude", "altitude", "heading", "hor_velocity", "ver_velocity", "altitude_type", "emitter_type", "tslc", "flags", "squawk"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ICAO_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CALLSIGN_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    HOR_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    VER_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_TYPE_FIELD_NUMBER: _ClassVar[int]
    EMITTER_TYPE_FIELD_NUMBER: _ClassVar[int]
    TSLC_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    SQUAWK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    icao_address: int
    callsign: str
    latitude: float
    longitude: float
    altitude: float
    heading: float
    hor_velocity: float
    ver_velocity: float
    altitude_type: int
    emitter_type: int
    tslc: _duration_pb2.Duration
    flags: int
    squawk: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., icao_address: _Optional[int] = ..., callsign: _Optional[str] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., altitude: _Optional[float] = ..., heading: _Optional[float] = ..., hor_velocity: _Optional[float] = ..., ver_velocity: _Optional[float] = ..., altitude_type: _Optional[int] = ..., emitter_type: _Optional[int] = ..., tslc: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., flags: _Optional[int] = ..., squawk: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class COReadIDRequest(_message.Message):
    __slots__ = ["header", "nodeid", "index", "subindex", "canopen_datatype"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NODEID_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    SUBINDEX_FIELD_NUMBER: _ClassVar[int]
    CANOPEN_DATATYPE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    nodeid: int
    index: int
    subindex: int
    canopen_datatype: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., nodeid: _Optional[int] = ..., index: _Optional[int] = ..., subindex: _Optional[int] = ..., canopen_datatype: _Optional[int] = ...) -> None: ...

class COReadIDResponse(_message.Message):
    __slots__ = ["header", "success", "data"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    data: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., data: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LinkPadding(_message.Message):
    __slots__ = ["link_name", "padding"]
    LINK_NAME_FIELD_NUMBER: _ClassVar[int]
    PADDING_FIELD_NUMBER: _ClassVar[int]
    link_name: str
    padding: float
    def __init__(self, link_name: _Optional[str] = ..., padding: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PowerState(_message.Message):
    __slots__ = ["header", "ros2_header", "voltage", "current", "power_consumption", "remaining_capacity", "relative_remaining_capacity", "connected", "charging", "time_remaining", "temperature"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    VOLTAGE_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    POWER_CONSUMPTION_FIELD_NUMBER: _ClassVar[int]
    REMAINING_CAPACITY_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_REMAINING_CAPACITY_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_FIELD_NUMBER: _ClassVar[int]
    CHARGING_FIELD_NUMBER: _ClassVar[int]
    TIME_REMAINING_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    voltage: float
    current: float
    power_consumption: float
    remaining_capacity: float
    relative_remaining_capacity: float
    connected: bool
    charging: bool
    time_remaining: float
    temperature: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., voltage: _Optional[float] = ..., current: _Optional[float] = ..., power_consumption: _Optional[float] = ..., remaining_capacity: _Optional[float] = ..., relative_remaining_capacity: _Optional[float] = ..., connected: bool = ..., charging: bool = ..., time_remaining: _Optional[float] = ..., temperature: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Gpgsa(_message.Message):
    __slots__ = ["header", "message_id", "auto_manual_mode", "fix_mode", "sv_ids", "pdop", "hdop", "vdop"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    AUTO_MANUAL_MODE_FIELD_NUMBER: _ClassVar[int]
    FIX_MODE_FIELD_NUMBER: _ClassVar[int]
    SV_IDS_FIELD_NUMBER: _ClassVar[int]
    PDOP_FIELD_NUMBER: _ClassVar[int]
    HDOP_FIELD_NUMBER: _ClassVar[int]
    VDOP_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    message_id: str
    auto_manual_mode: str
    fix_mode: int
    sv_ids: _containers.RepeatedScalarFieldContainer[int]
    pdop: float
    hdop: float
    vdop: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., message_id: _Optional[str] = ..., auto_manual_mode: _Optional[str] = ..., fix_mode: _Optional[int] = ..., sv_ids: _Optional[_Iterable[int]] = ..., pdop: _Optional[float] = ..., hdop: _Optional[float] = ..., vdop: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import transform_stamped_pb2 as _transform_stamped_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import allowed_collision_matrix_pb2 as _allowed_collision_matrix_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import link_padding_pb2 as _link_padding_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import link_scale_pb2 as _link_scale_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import object_color_pb2 as _object_color_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_world_pb2 as _planning_scene_world_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import robot_state_pb2 as _robot_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlanningScene(_message.Message):
    __slots__ = ["name", "robot_state", "robot_model_name", "fixed_frame_transforms", "allowed_collision_matrix", "link_padding", "link_scale", "object_colors", "world", "is_diff"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ROBOT_STATE_FIELD_NUMBER: _ClassVar[int]
    ROBOT_MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    FIXED_FRAME_TRANSFORMS_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_COLLISION_MATRIX_FIELD_NUMBER: _ClassVar[int]
    LINK_PADDING_FIELD_NUMBER: _ClassVar[int]
    LINK_SCALE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_COLORS_FIELD_NUMBER: _ClassVar[int]
    WORLD_FIELD_NUMBER: _ClassVar[int]
    IS_DIFF_FIELD_NUMBER: _ClassVar[int]
    name: str
    robot_state: _robot_state_pb2.RobotState
    robot_model_name: str
    fixed_frame_transforms: _containers.RepeatedCompositeFieldContainer[_transform_stamped_pb2.TransformStamped]
    allowed_collision_matrix: _allowed_collision_matrix_pb2.AllowedCollisionMatrix
    link_padding: _containers.RepeatedCompositeFieldContainer[_link_padding_pb2.LinkPadding]
    link_scale: _containers.RepeatedCompositeFieldContainer[_link_scale_pb2.LinkScale]
    object_colors: _containers.RepeatedCompositeFieldContainer[_object_color_pb2.ObjectColor]
    world: _planning_scene_world_pb2.PlanningSceneWorld
    is_diff: bool
    def __init__(self, name: _Optional[str] = ..., robot_state: _Optional[_Union[_robot_state_pb2.RobotState, _Mapping]] = ..., robot_model_name: _Optional[str] = ..., fixed_frame_transforms: _Optional[_Iterable[_Union[_transform_stamped_pb2.TransformStamped, _Mapping]]] = ..., allowed_collision_matrix: _Optional[_Union[_allowed_collision_matrix_pb2.AllowedCollisionMatrix, _Mapping]] = ..., link_padding: _Optional[_Iterable[_Union[_link_padding_pb2.LinkPadding, _Mapping]]] = ..., link_scale: _Optional[_Iterable[_Union[_link_scale_pb2.LinkScale, _Mapping]]] = ..., object_colors: _Optional[_Iterable[_Union[_object_color_pb2.ObjectColor, _Mapping]]] = ..., world: _Optional[_Union[_planning_scene_world_pb2.PlanningSceneWorld, _Mapping]] = ..., is_diff: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IntegerRange(_message.Message):
    __slots__ = ["from_value", "to_value", "step"]
    FROM_VALUE_FIELD_NUMBER: _ClassVar[int]
    TO_VALUE_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    from_value: int
    to_value: int
    step: int
    def __init__(self, from_value: _Optional[int] = ..., to_value: _Optional[int] = ..., step: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TimedSwitch(_message.Message):
    __slots__ = ["switch_mode", "num_cycles", "pulse_pattern"]
    SWITCH_MODE_FIELD_NUMBER: _ClassVar[int]
    NUM_CYCLES_FIELD_NUMBER: _ClassVar[int]
    PULSE_PATTERN_FIELD_NUMBER: _ClassVar[int]
    switch_mode: int
    num_cycles: int
    pulse_pattern: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, switch_mode: _Optional[int] = ..., num_cycles: _Optional[int] = ..., pulse_pattern: _Optional[_Iterable[float]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduleChangeProgress(_message.Message):
    __slots__ = ["has_progress", "version", "checkpoints"]
    HAS_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CHECKPOINTS_FIELD_NUMBER: _ClassVar[int]
    has_progress: bool
    version: int
    checkpoints: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, has_progress: bool = ..., version: _Optional[int] = ..., checkpoints: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PrimaryControl(_message.Message):
    __slots__ = ["header", "active", "estop", "steering_command", "throttle_command", "brake_command"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    ESTOP_FIELD_NUMBER: _ClassVar[int]
    STEERING_COMMAND_FIELD_NUMBER: _ClassVar[int]
    THROTTLE_COMMAND_FIELD_NUMBER: _ClassVar[int]
    BRAKE_COMMAND_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    active: bool
    estop: bool
    steering_command: float
    throttle_command: float
    brake_command: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., active: bool = ..., estop: bool = ..., steering_command: _Optional[float] = ..., throttle_command: _Optional[float] = ..., brake_command: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mola_msgs/srv/relocalize_from_gnss.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/mola_msgs/srv/relocalize_from_gnss.proto\x12(make87_messages_ros2.jazzy.mola_msgs.srv\"\x1b\n\x19RelocalizeFromGNSSRequest\".\n\x1aRelocalizeFromGNSSResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mola_msgs.srv.relocalize_from_gnss_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RELOCALIZEFROMGNSSREQUEST']._serialized_start=113
  _globals['_RELOCALIZEFROMGNSSREQUEST']._serialized_end=140
  _globals['_RELOCALIZEFROMGNSSRESPONSE']._serialized_start=142
  _globals['_RELOCALIZEFROMGNSSRESPONSE']._serialized_end=188
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NodeDetailsRequest(_message.Message):
    __slots__ = ["header", "node"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    node: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., node: _Optional[str] = ...) -> None: ...

class NodeDetailsResponse(_message.Message):
    __slots__ = ["header", "subscribing", "publishing", "services"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIBING_FIELD_NUMBER: _ClassVar[int]
    PUBLISHING_FIELD_NUMBER: _ClassVar[int]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    subscribing: _containers.RepeatedScalarFieldContainer[str]
    publishing: _containers.RepeatedScalarFieldContainer[str]
    services: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., subscribing: _Optional[_Iterable[str]] = ..., publishing: _Optional[_Iterable[str]] = ..., services: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ds_dbw_msgs/msg/brake_diagnostics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/ds_dbw_msgs/msg/brake_diagnostics.proto\x12*make87_messages_ros2.jazzy.ds_dbw_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xf8\x0c\n\x10\x42rakeDiagnostics\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x10\n\x08\x64\x65graded\x18\x02 \x01(\x08\x12\x19\n\x11\x64\x65graded_cmd_type\x18\x03 \x01(\x08\x12\x16\n\x0e\x64\x65graded_comms\x18\x04 \x01(\x08\x12\x1a\n\x12\x64\x65graded_comms_dbw\x18\x05 \x01(\x08\x12\"\n\x1a\x64\x65graded_comms_dbw_gateway\x18\x06 \x01(\x08\x12 \n\x18\x64\x65graded_comms_dbw_steer\x18\x07 \x01(\x08\x12 \n\x18\x64\x65graded_comms_dbw_thrtl\x18\x08 \x01(\x08\x12\x1f\n\x17\x64\x65graded_comms_dbw_gear\x18\t \x01(\x08\x12\x1e\n\x16\x64\x65graded_comms_vehicle\x18\n \x01(\x08\x12\x1f\n\x17\x64\x65graded_comms_actuator\x18\x0b \x01(\x08\x12!\n\x19\x64\x65graded_comms_actuator_1\x18\x0c \x01(\x08\x12!\n\x19\x64\x65graded_comms_actuator_2\x18\r \x01(\x08\x12\x19\n\x11\x64\x65graded_internal\x18\x0e \x01(\x08\x12$\n\x1c\x64\x65graded_control_performance\x18\x0f \x01(\x08\x12\x1f\n\x17\x64\x65graded_param_mismatch\x18\x10 \x01(\x08\x12\x1f\n\x17\x64\x65graded_btsi_stuck_low\x18\x11 \x01(\x08\x12 \n\x18\x64\x65graded_btsi_stuck_high\x18\x12 \x01(\x08\x12\x18\n\x10\x64\x65graded_vehicle\x18\x13 \x01(\x08\x12\x1e\n\x16\x64\x65graded_vehicle_speed\x18\x14 \x01(\x08\x12\x1e\n\x16\x64\x65graded_bped_feedback\x18\x15 \x01(\x08\x12\x19\n\x11\x64\x65graded_actuator\x18\x16 \x01(\x08\x12\x1b\n\x13\x64\x65graded_actuator_1\x18\x17 \x01(\x08\x12\x1b\n\x13\x64\x65graded_actuator_2\x18\x18 \x01(\x08\x12\"\n\x1a\x64\x65graded_actuator_aeb_deny\x18\x19 \x01(\x08\x12\x1e\n\x16\x64\x65graded_actuator_warm\x18\x1a \x01(\x08\x12\x1c\n\x14\x64\x65graded_calibration\x18\x1b \x01(\x08\x12\r\n\x05\x66\x61ult\x18\x1c \x01(\x08\x12\x13\n\x0b\x66\x61ult_power\x18\x1d \x01(\x08\x12\x13\n\x0b\x66\x61ult_comms\x18\x1e \x01(\x08\x12\x16\n\x0e\x66\x61ult_internal\x18\x1f \x01(\x08\x12\x15\n\rfault_vehicle\x18  \x01(\x08\x12\x16\n\x0e\x66\x61ult_actuator\x18! \x01(\x08\x12\x17\n\x0f\x66\x61ult_comms_dbw\x18\" \x01(\x08\x12\x1f\n\x17\x66\x61ult_comms_dbw_gateway\x18# \x01(\x08\x12\x1d\n\x15\x66\x61ult_comms_dbw_steer\x18$ \x01(\x08\x12\x1d\n\x15\x66\x61ult_comms_dbw_thrtl\x18% \x01(\x08\x12\x1c\n\x14\x66\x61ult_comms_dbw_gear\x18& \x01(\x08\x12\x1b\n\x13\x66\x61ult_comms_vehicle\x18\' \x01(\x08\x12\x1c\n\x14\x66\x61ult_comms_actuator\x18( \x01(\x08\x12\x1e\n\x16\x66\x61ult_comms_actuator_1\x18) \x01(\x08\x12\x1e\n\x16\x66\x61ult_comms_actuator_2\x18* \x01(\x08\x12\x1b\n\x13\x66\x61ult_vehicle_speed\x18+ \x01(\x08\x12\x1f\n\x17\x66\x61ult_actuator_acc_deny\x18, \x01(\x08\x12#\n\x1b\x66\x61ult_actuator_pedal_sensor\x18- \x01(\x08\x12\x1b\n\x13\x66\x61ult_bped_sensor_1\x18. \x01(\x08\x12\x1b\n\x13\x66\x61ult_bped_sensor_2\x18/ \x01(\x08\x12\"\n\x1a\x66\x61ult_bped_sensor_mismatch\x18\x30 \x01(\x08\x12\x18\n\x10\x66\x61ult_actuator_1\x18\x31 \x01(\x08\x12\x18\n\x10\x66\x61ult_actuator_2\x18\x32 \x01(\x08\x12!\n\x19\x66\x61ult_control_performance\x18\x33 \x01(\x08\x12\x1c\n\x14\x66\x61ult_param_mismatch\x18\x34 \x01(\x08\x12\x1a\n\x12\x66\x61ult_param_limits\x18\x35 \x01(\x08\x12\x19\n\x11\x66\x61ult_calibration\x18\x36 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ds_dbw_msgs.msg.brake_diagnostics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BRAKEDIAGNOSTICS']._serialized_start=169
  _globals['_BRAKEDIAGNOSTICS']._serialized_end=1825
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_planning_msgs/msg/lanelet_route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.autoware_planning_msgs.msg import lanelet_segment_pb2 as make87__messages__ros2_dot_rolling_dot_autoware__planning__msgs_dot_msg_dot_lanelet__segment__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.rolling.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_rolling_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/autoware_planning_msgs/msg/lanelet_route.proto\x12\x37make87_messages_ros2.rolling.autoware_planning_msgs.msg\x1aMmake87_messages_ros2/rolling/autoware_planning_msgs/msg/lanelet_segment.proto\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\x1a\x42make87_messages_ros2/rolling/unique_identifier_msgs/msg/uuid.proto\"\xa8\x03\n\x0cLaneletRoute\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12H\n\nstart_pose\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12G\n\tgoal_pose\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12Y\n\x08segments\x18\x04 \x03(\x0b\x32G.make87_messages_ros2.rolling.autoware_planning_msgs.msg.LaneletSegment\x12K\n\x04uuid\x18\x05 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12\x1a\n\x12\x61llow_modification\x18\x06 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_planning_msgs.msg.lanelet_route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LANELETROUTE']._serialized_start=399
  _globals['_LANELETROUTE']._serialized_end=823
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.sensor_msgs.msg import joy_feedback_pb2 as _joy_feedback_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class JoyFeedbackArray(_message.Message):
    __slots__ = ["array"]
    ARRAY_FIELD_NUMBER: _ClassVar[int]
    array: _containers.RepeatedCompositeFieldContainer[_joy_feedback_pb2.JoyFeedback]
    def __init__(self, array: _Optional[_Iterable[_Union[_joy_feedback_pb2.JoyFeedback, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/yasmin_msgs/msg/state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.yasmin_msgs.msg import transition_pb2 as make87__messages__ros2_dot_rolling_dot_yasmin__msgs_dot_msg_dot_transition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/rolling/yasmin_msgs/msg/state.proto\x12,make87_messages_ros2.rolling.yasmin_msgs.msg\x1a=make87_messages_ros2/rolling/yasmin_msgs/msg/transition.proto\"\xb9\x01\n\x05State\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0e\n\x06parent\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12M\n\x0btransitions\x18\x04 \x03(\x0b\x32\x38.make87_messages_ros2.rolling.yasmin_msgs.msg.Transition\x12\x10\n\x08outcomes\x18\x05 \x03(\t\x12\x0e\n\x06is_fsm\x18\x06 \x01(\x08\x12\x15\n\rcurrent_state\x18\x07 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.yasmin_msgs.msg.state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STATE']._serialized_start=170
  _globals['_STATE']._serialized_end=355
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import polygon_pb2 as _polygon_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SolidPrimitive(_message.Message):
    __slots__ = ["type", "dimensions", "polygon"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    POLYGON_FIELD_NUMBER: _ClassVar[int]
    type: int
    dimensions: _containers.RepeatedScalarFieldContainer[float]
    polygon: _polygon_pb2.Polygon
    def __init__(self, type: _Optional[int] = ..., dimensions: _Optional[_Iterable[float]] = ..., polygon: _Optional[_Union[_polygon_pb2.Polygon, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.lifecycle_msgs.msg import state_pb2 as _state_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetHardwareComponentStateRequest(_message.Message):
    __slots__ = ["name", "target_state"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TARGET_STATE_FIELD_NUMBER: _ClassVar[int]
    name: str
    target_state: _state_pb2.State
    def __init__(self, name: _Optional[str] = ..., target_state: _Optional[_Union[_state_pb2.State, _Mapping]] = ...) -> None: ...

class SetHardwareComponentStateResponse(_message.Message):
    __slots__ = ["ok", "state"]
    OK_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    ok: bool
    state: _state_pb2.State
    def __init__(self, ok: bool = ..., state: _Optional[_Union[_state_pb2.State, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SrrDebug3(_message.Message):
    __slots__ = ["header", "ros2_header", "timer_create_error", "thread_create_error", "arm_calibration_error", "spi_fee_error", "spi_comm_error", "socket_write_error", "dsp_cal_obsolete_62_error", "socket_read_error", "socket_init_error", "signal_wait_error", "signal_send_error", "signal_create_error", "shared_mem_write_error", "shared_mem_read_error", "shared_mem_config_error", "share_mem_init_error", "ram_test_error", "num_errors", "mmap_memory_error", "isr_attach_error", "ipc_drv_write_error", "ipc_drv_trigger_error", "ipc_drv_sync_error", "ipc_drv_read_error", "ipc_drv_init_error", "interrupt_enable_error", "hil_format_error", "flash_filesystem_error", "error_none", "dsp_load_read_error", "dsp_load_open_error", "dsp_load_address_error", "dsp_isp_write_error", "dsp_ipc_read_error", "dsp_ipc_init", "dsp_init_error", "dsp_drv_start_error", "dsp_drv_load_error", "dsp_drv_init_error", "dsp_drv_init2_error", "dsp_drv_init1_error", "dsp_calibration_error", "can_xmt_error", "can_rcv_error", "can_hardware_error", "always_true"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    TIMER_CREATE_ERROR_FIELD_NUMBER: _ClassVar[int]
    THREAD_CREATE_ERROR_FIELD_NUMBER: _ClassVar[int]
    ARM_CALIBRATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    SPI_FEE_ERROR_FIELD_NUMBER: _ClassVar[int]
    SPI_COMM_ERROR_FIELD_NUMBER: _ClassVar[int]
    SOCKET_WRITE_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_CAL_OBSOLETE_62_ERROR_FIELD_NUMBER: _ClassVar[int]
    SOCKET_READ_ERROR_FIELD_NUMBER: _ClassVar[int]
    SOCKET_INIT_ERROR_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_WAIT_ERROR_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_SEND_ERROR_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_CREATE_ERROR_FIELD_NUMBER: _ClassVar[int]
    SHARED_MEM_WRITE_ERROR_FIELD_NUMBER: _ClassVar[int]
    SHARED_MEM_READ_ERROR_FIELD_NUMBER: _ClassVar[int]
    SHARED_MEM_CONFIG_ERROR_FIELD_NUMBER: _ClassVar[int]
    SHARE_MEM_INIT_ERROR_FIELD_NUMBER: _ClassVar[int]
    RAM_TEST_ERROR_FIELD_NUMBER: _ClassVar[int]
    NUM_ERRORS_FIELD_NUMBER: _ClassVar[int]
    MMAP_MEMORY_ERROR_FIELD_NUMBER: _ClassVar[int]
    ISR_ATTACH_ERROR_FIELD_NUMBER: _ClassVar[int]
    IPC_DRV_WRITE_ERROR_FIELD_NUMBER: _ClassVar[int]
    IPC_DRV_TRIGGER_ERROR_FIELD_NUMBER: _ClassVar[int]
    IPC_DRV_SYNC_ERROR_FIELD_NUMBER: _ClassVar[int]
    IPC_DRV_READ_ERROR_FIELD_NUMBER: _ClassVar[int]
    IPC_DRV_INIT_ERROR_FIELD_NUMBER: _ClassVar[int]
    INTERRUPT_ENABLE_ERROR_FIELD_NUMBER: _ClassVar[int]
    HIL_FORMAT_ERROR_FIELD_NUMBER: _ClassVar[int]
    FLASH_FILESYSTEM_ERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_NONE_FIELD_NUMBER: _ClassVar[int]
    DSP_LOAD_READ_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_LOAD_OPEN_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_LOAD_ADDRESS_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_ISP_WRITE_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_IPC_READ_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_IPC_INIT_FIELD_NUMBER: _ClassVar[int]
    DSP_INIT_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_DRV_START_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_DRV_LOAD_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_DRV_INIT_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_DRV_INIT2_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_DRV_INIT1_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_CALIBRATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    CAN_XMT_ERROR_FIELD_NUMBER: _ClassVar[int]
    CAN_RCV_ERROR_FIELD_NUMBER: _ClassVar[int]
    CAN_HARDWARE_ERROR_FIELD_NUMBER: _ClassVar[int]
    ALWAYS_TRUE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    timer_create_error: bool
    thread_create_error: bool
    arm_calibration_error: bool
    spi_fee_error: bool
    spi_comm_error: bool
    socket_write_error: bool
    dsp_cal_obsolete_62_error: bool
    socket_read_error: bool
    socket_init_error: bool
    signal_wait_error: bool
    signal_send_error: bool
    signal_create_error: bool
    shared_mem_write_error: bool
    shared_mem_read_error: bool
    shared_mem_config_error: bool
    share_mem_init_error: bool
    ram_test_error: bool
    num_errors: bool
    mmap_memory_error: bool
    isr_attach_error: bool
    ipc_drv_write_error: bool
    ipc_drv_trigger_error: bool
    ipc_drv_sync_error: bool
    ipc_drv_read_error: bool
    ipc_drv_init_error: bool
    interrupt_enable_error: bool
    hil_format_error: bool
    flash_filesystem_error: bool
    error_none: bool
    dsp_load_read_error: bool
    dsp_load_open_error: bool
    dsp_load_address_error: bool
    dsp_isp_write_error: bool
    dsp_ipc_read_error: bool
    dsp_ipc_init: bool
    dsp_init_error: bool
    dsp_drv_start_error: bool
    dsp_drv_load_error: bool
    dsp_drv_init_error: bool
    dsp_drv_init2_error: bool
    dsp_drv_init1_error: bool
    dsp_calibration_error: bool
    can_xmt_error: bool
    can_rcv_error: bool
    can_hardware_error: bool
    always_true: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., timer_create_error: bool = ..., thread_create_error: bool = ..., arm_calibration_error: bool = ..., spi_fee_error: bool = ..., spi_comm_error: bool = ..., socket_write_error: bool = ..., dsp_cal_obsolete_62_error: bool = ..., socket_read_error: bool = ..., socket_init_error: bool = ..., signal_wait_error: bool = ..., signal_send_error: bool = ..., signal_create_error: bool = ..., shared_mem_write_error: bool = ..., shared_mem_read_error: bool = ..., shared_mem_config_error: bool = ..., share_mem_init_error: bool = ..., ram_test_error: bool = ..., num_errors: bool = ..., mmap_memory_error: bool = ..., isr_attach_error: bool = ..., ipc_drv_write_error: bool = ..., ipc_drv_trigger_error: bool = ..., ipc_drv_sync_error: bool = ..., ipc_drv_read_error: bool = ..., ipc_drv_init_error: bool = ..., interrupt_enable_error: bool = ..., hil_format_error: bool = ..., flash_filesystem_error: bool = ..., error_none: bool = ..., dsp_load_read_error: bool = ..., dsp_load_open_error: bool = ..., dsp_load_address_error: bool = ..., dsp_isp_write_error: bool = ..., dsp_ipc_read_error: bool = ..., dsp_ipc_init: bool = ..., dsp_init_error: bool = ..., dsp_drv_start_error: bool = ..., dsp_drv_load_error: bool = ..., dsp_drv_init_error: bool = ..., dsp_drv_init2_error: bool = ..., dsp_drv_init1_error: bool = ..., dsp_calibration_error: bool = ..., can_xmt_error: bool = ..., can_rcv_error: bool = ..., can_hardware_error: bool = ..., always_true: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsfINS(_message.Message):
    __slots__ = ["header", "bitfield0", "reserved1", "i_tow", "x_ang_rate", "y_ang_rate", "z_ang_rate", "x_accel", "y_accel", "z_accel"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BITFIELD0_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    X_ANG_RATE_FIELD_NUMBER: _ClassVar[int]
    Y_ANG_RATE_FIELD_NUMBER: _ClassVar[int]
    Z_ANG_RATE_FIELD_NUMBER: _ClassVar[int]
    X_ACCEL_FIELD_NUMBER: _ClassVar[int]
    Y_ACCEL_FIELD_NUMBER: _ClassVar[int]
    Z_ACCEL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    bitfield0: int
    reserved1: _containers.RepeatedScalarFieldContainer[int]
    i_tow: int
    x_ang_rate: int
    y_ang_rate: int
    z_ang_rate: int
    x_accel: int
    y_accel: int
    z_accel: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., bitfield0: _Optional[int] = ..., reserved1: _Optional[_Iterable[int]] = ..., i_tow: _Optional[int] = ..., x_ang_rate: _Optional[int] = ..., y_ang_rate: _Optional[int] = ..., z_ang_rate: _Optional[int] = ..., x_accel: _Optional[int] = ..., y_accel: _Optional[int] = ..., z_accel: _Optional[int] = ...) -> None: ...
